@@ -210,14 +210,16 @@ class Cache:
                 if django_instance_fields_value != redis_field_value:
                     changed_many_to_many_fields_to_update[redis_field_name] = redis_field_value
             if self.cache_conf['write_to_django']:
-                django_model.objects.filter(id=django_id).update(**changed_fields_to_update)
-                print('updated', django_id)
-                self.update_django_many_to_many(
-                    django_model,
-                    django_id,
-                    changed_many_to_many_fields_to_update
-                )
+                if changed_fields_to_update.keys():
+                    django_model.objects.filter(id=django_id).update(**changed_fields_to_update)
+                if changed_many_to_many_fields_to_update:
+                    self.update_django_many_to_many(
+                        django_model,
+                        django_id,
+                        changed_many_to_many_fields_to_update
+                    )
                 django_instance = django_model.objects.filter(id=django_id)[0]
+                print('updated', django_id)
             else:
                 print(f'\n'
                       f'{datetime.datetime.now()} - '
