@@ -23,22 +23,29 @@ class RedisQuerySet(django_models.query.QuerySet):
         id = create_result.id
         existing_fields = {}
         redis_root = get_redis_root()
+        for field in create_result.__class__._meta.get_fields():
+            try:
+                field_name = field.name
+                if field_name in ['id', 'pk']:
+                    field_name = 'django_id'
+                value = django_instance_field_to_redis_value(
+                    redis_root,
+                    create_result,
+                    field,
+                    redis_root.get_cache_conf(self.__class__)
+                )
+                if issubclass(value.__class__, django_models.Model):
+                    field_name = field_name + '_id'
+                    value = value.id
+                existing_fields[field_name] = value
+            except:
+                pass
         existing_redis_instances = redis_root.get(self.model, create_result.id)
-        if not existing_redis_instances:
-            for field in create_result.__class__._meta.get_fields():
-                try:
-                    field_name = field.name
-                    if field_name in ['id', 'pk']:
-                        field_name = 'django_id'
-                    existing_fields[field_name] = django_instance_field_to_redis_value(
-                        redis_root,
-                        create_result,
-                        field,
-                        redis_root.get_cache_conf(self.__class__)
-                    )
-                except:
-                    pass
+        if existing_redis_instances:
+            redis_root.update(self.model, existing_redis_instances, **existing_fields)
+        else:
             redis_root.create(self.model, **existing_fields)
+
         return create_result
 
     def delete(self):
@@ -204,7 +211,9 @@ class DjangoRedisModel(django_models.Model):
                 )
             except:
                 pass
-        redis_root.create(self.__class__, **existing_fields)
+        redis_instance_qs = redis_root.get(self.__class__, django_id=self.id)
+        if redis_instance_qs:
+            redis_root.update(self.__class__, redis_instance_qs, **existing_fields)
         return self
 
     def delete(self, *args, **kwargs):
@@ -245,7 +254,9 @@ class DjangoRedisUserModel(AbstractUser):
                 )
             except:
                 pass
-        redis_root.create(self.__class__, **existing_fields)
+        redis_instance_qs = redis_root.get(self.__class__, django_id=self.id)
+        if redis_instance_qs:
+            redis_root.update(self.__class__, redis_instance_qs, **existing_fields)
         return self
 
     def delete(self, *args, **kwargs):
@@ -253,9 +264,13 @@ class DjangoRedisUserModel(AbstractUser):
         delete_result = super().delete(*args, **kwargs)
         redis_root = get_redis_root()
         redis_instance_qs = redis_root.get(self.__class__, django_id=django_id)
+        print('model pre delete: ', len(redis_instance_qs))
         if redis_instance_qs:
             print(self.__class__)
             redis_root.delete(self.__class__, redis_instance_qs)
+            redis_instance_qs = redis_root.get(self.__class__, django_id=django_id)
+            print('model post delete: ', len(redis_instance_qs))
+
         return self
 
     class Meta:
